<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>ExecutionWindow</name>
    <message>
        <location filename="../executer/executionwindow.ui" line="14"/>
        <source>Execution window</source>
        <translation>Fenêtre d&apos;exécution</translation>
    </message>
    <message>
        <location filename="../executer/executionwindow.ui" line="28"/>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <location filename="../executer/executionwindow.ui" line="48"/>
        <source>Debug</source>
        <translation>Debug</translation>
    </message>
    <message>
        <location filename="../executer/executionwindow.ui" line="74"/>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
</context>
<context>
    <name>LibExecuter::CodeConsole</name>
    <message>
        <source>Warning: </source>
        <translation type="obsolete">Avertissement :</translation>
    </message>
</context>
<context>
    <name>LibExecuter::CodeStdio</name>
    <message>
        <source>Warning: </source>
        <translation type="obsolete">Avertissement : </translation>
    </message>
    <message>
        <source>Error: </source>
        <translation type="obsolete">Erreur : </translation>
    </message>
    <message>
        <location filename="../executer/codestdio.cpp" line="49"/>
        <source>Warning: %1</source>
        <translation>Avertissement : %1</translation>
    </message>
    <message>
        <location filename="../executer/codestdio.cpp" line="56"/>
        <source>Warning: %1
</source>
        <translation>Avertissement : %1
</translation>
    </message>
    <message>
        <location filename="../executer/codestdio.cpp" line="63"/>
        <source>Error: %1</source>
        <translation>Erreur : %1</translation>
    </message>
    <message>
        <location filename="../executer/codestdio.cpp" line="70"/>
        <source>Error: %1
</source>
        <translation>Erreur : %1
</translation>
    </message>
</context>
<context>
    <name>LibExecuter::Executer</name>
    <message>
        <location filename="../executer/executer.cpp" line="329"/>
        <source>Invalid image resource</source>
        <translation>Ressource d&apos;image invalide</translation>
    </message>
    <message>
        <location filename="../executer/executer.cpp" line="362"/>
        <source>Invalid Begin procedure action, you have to end the previous procedure before starting another one</source>
        <translation>Début de procédure incorrect, vous devez d&apos;abord terminer la procédure précédente avant d&apos;en débuter une autre</translation>
    </message>
    <message>
        <location filename="../executer/executer.cpp" line="374"/>
        <source>A procedure name cannot be empty</source>
        <translation>Le nom d&apos;une procédure ne peut être vide</translation>
    </message>
    <message>
        <location filename="../executer/executer.cpp" line="381"/>
        <source>A procedure with the name &quot;%1&quot; has already been declared</source>
        <translation>Une procédure nommée &quot;%1&quot; existe déjà</translation>
    </message>
    <message>
        <location filename="../executer/executer.cpp" line="392"/>
        <source>Invalid End procedure</source>
        <translation>Fin de procédure incorrecte</translation>
    </message>
    <message>
        <location filename="../executer/executer.cpp" line="414"/>
        <source>Begin procedure action without end procedure</source>
        <translation>Début de procédure sans fin de procédure</translation>
    </message>
    <message>
        <location filename="../executer/executer.cpp" line="428"/>
        <source>Incorrect parameter name: &quot;%1&quot;</source>
        <translation>Nom de paramètre incorrect : &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../executer/executer.cpp" line="443"/>
        <source>Error while evaluating parameter &quot;%1&quot;, error message: &quot;%2&quot;</source>
        <translation>Erreur lors de l&apos;évaluation du paramètre &quot;%1&quot;, message d&apos;erreur : &quot;%2&quot;</translation>
    </message>
    <message>
        <location filename="../executer/executer.cpp" line="600"/>
        <source>Action design error: Invalid exception emitted (%1, line %2)</source>
        <translation>Erreur de conception de l&apos;action : Exception invalide émise (%1, ligne %2)</translation>
    </message>
    <message>
        <location filename="../executer/executer.cpp" line="629"/>
        <source>Invalid exception line: %1</source>
        <translation>Ligne d&apos;exception invalide : %1</translation>
    </message>
    <message>
        <location filename="../executer/executer.cpp" line="652"/>
        <source>Script line %1: </source>
        <translation>Ligne de script %1 : </translation>
    </message>
    <message>
        <source>Script %1, line %2: </source>
        <translation type="obsolete">Script %1, ligne %2 : </translation>
    </message>
    <message>
        <location filename="../executer/executer.cpp" line="717"/>
        <source>Unable to find the label named &quot;%1&quot;</source>
        <translation>Impossible de trouver le label nommé &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../executer/executer.cpp" line="731"/>
        <source>Incorrect Script.nextLine value: %1</source>
        <translation>Valeur de Script.nextLine incorrecte : %1</translation>
    </message>
    <message>
        <location filename="../executer/executer.cpp" line="734"/>
        <source>The action at line %1 is invalid</source>
        <translation>L&apos;action à la ligne %1 est invalide</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../executer/codeinitializer.cpp" line="51"/>
        <source>Unable to load UI file %1</source>
        <translation>Impossible de charger le fichier UI %1</translation>
    </message>
    <message>
        <location filename="../executer/codeinitializer.cpp" line="64"/>
        <source>Unable to include file %1</source>
        <translation>Impossible d&apos;include le fichier %1</translation>
    </message>
</context>
</TS>
